====================
 json-merger v0.7.0
====================

json-merger v0.7.0 was released on October 23 2018.

About
-----

Python module that is able to merge json record objects.

*This is an experimental developer preview release.*

What's new
----------

- Add a new strategy for conflicts on head delete (contrib).

Installation
------------

   $ pip install json-merger==0.7.0

Documentation
-------------

   http://pythonhosted.org/json-merger/

Happy hacking and thanks for flying json-merger.

| Invenio Development Team
|   Email: admin@inspirehep.net
|   Twitter: http://twitter.com/inspirehep
|   GitHub: https://github.com/inspirehep/json-merger
|   URL: http://inspirehep.org
